==> mozc_1.6.1187.102.orig.tar.gz: mozc-1.6.1187.102/net/json_util.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_NET_JSON_UTIL_H_
#define MOZC_NET_JSON_UTIL_H_

#include "base/base.h"
#include "base/protobuf/message.h"
#include "net/jsoncpp.h"

namespace mozc {
namespace net {

class JsonUtil {
 public:
  static bool ProtobufMessageToJsonValue(
      const protobuf::Message &message, Json::Value *value);
  static bool JsonValueToProtobufMessage(
      const Json::Value &value, protobuf::Message *message);

 private:
  JsonUtil() {}
  ~JsonUtil() {}

  DISALLOW_COPY_AND_ASSIGN(JsonUtil);
};

}  // namespace net
}  // namespace mozc

#endif  // MOZC_NET_JSON_UTIL_H_

==> mozc_1.15.1857.102.orig.tar.gz: mozc-1.15.1857.102/net/json_util.h <==
// Copyright 2010-2014, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_NET_JSON_UTIL_H_
#define MOZC_NET_JSON_UTIL_H_

#include "base/port.h"
#include "base/protobuf/message.h"
#include "net/jsoncpp.h"

namespace mozc {
namespace net {

class JsonUtil {
 public:
  // Converts protobuf message to JSON value.
  // Note: JavaScript JSON parser can't handle int64/uint64.
  // So it converts int64/uint64 value in protobuf to string value in JSON.
  static bool ProtobufMessageToJsonValue(
      const protobuf::Message &message, Json::Value *value);
  // Converts JSON value to protobuf message.
  static bool JsonValueToProtobufMessage(
      const Json::Value &value, protobuf::Message *message);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(JsonUtil);
};

}  // namespace net
}  // namespace mozc

#endif  // MOZC_NET_JSON_UTIL_H_
